@@ -39,10 +39,6 @@ int sa_open_memory() {
 	if (kernel_version < 11)
 		return ENOTSUP;
 
-	file_meminfo = fopen("/proc/meminfo", "r");
-	if (file_meminfo == NULL)
-		return EIO;
-
 	return 0;
 }
 
@@ -56,9 +52,11 @@ int sa_get_memory(struct sa_memory* dst) {
 	if (dst == NULL)
 		return EINVAL;
 
-	rewind(file_meminfo);
-	if (fflush(file_meminfo) != 0)
-		return EIO;
+	if (file_meminfo != NULL)
+		fclose(file_meminfo);
+	file_meminfo = fopen("/proc/meminfo", "r");
+        if (file_meminfo == NULL)
+        	return EIO;
 
 	int aux = 0; // for better performance
 	while (fgets(m_line_buffer, sizeof(m_line_buffer), file_meminfo) != NULL) {
