@@ -1,7 +1,7 @@
 /*
  * libsysactivity
  * http://sourceforge.net/projects/libsysactivity/
- * Copyright (c) 2010 Carlos Olmedo Escobar <carlos.olmedo.e@gmail.com>
+ * Copyright (c) 2010-2011 Carlos Olmedo Escobar <carlos.olmedo.e@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,8 +23,8 @@
 
 int kernel_version;
 
-char* skip_values(char* pos, int number);
-char* skip_value(char* pos);
-inline void strlcpy(char* dest, char* src, int n);
+char* skip_values(char* pos, int number) SA_NONNULL;
+char* skip_value(char* pos) SA_NONNULL SA_HOT;
+SA_INLINE void strlcpy(char* __restrict__ dest, const char* __restrict__ src, const size_t n) SA_NONNULL;
 
 #endif /* UTILS_H_ */
