@@ -18,6 +18,8 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#include <errno.h>
+#include <stdlib.h>
 #include "utils.h"
 
 int get_ks(kstat_ctl_t* kc, kstat_t** ks, char* module, char* name) {
@@ -30,3 +32,15 @@ int get_ks(kstat_ctl_t* kc, kstat_t** ks, char* module, char* name) {
 
 	return 0;
 }
+
+int safe_realloc(void** ptr, size_t* size) {
+	void* tmp = realloc(*ptr, *size);
+	if (tmp == NULL) {
+		free(*ptr);
+		*ptr = NULL;
+		*size = 0;
+		return ENOMEM;
+	}
+	*ptr = tmp;
+	return 0;
+}
