@@ -19,6 +19,6 @@
  */
 
 #include <kstat.h>
-#include <errno.h>
 
-int get_ks(kstat_ctl_t* kc, kstat_t** ks, char* module, char* name);
+int get_ks(kstat_ctl_t* kc, kstat_t** ks, char* module, char* name) SA_HOT SA_NONNULL;
+int safe_realloc(void** ptr, size_t* size) SA_NONNULL;
