@@ -28,7 +28,7 @@
 /** \struct sa_cpu cpu.h
  * This structure gathers the details about one cpu's activity.
  */
-SA_EXPORT struct sa_cpu {
+struct sa_cpu {
 #ifdef SA_CPU_ID
 	uint16_t id; //!< Cpu identificator. 0 is the first one.
 #endif
