@@ -28,7 +28,7 @@
 /** \struct sa_memory memory.h
  * This structure gathers the details about the memory usage. Each value is measured in bytes.
  */
-SA_EXPORT struct sa_memory {
+struct sa_memory {
 #ifdef SA_MEMORY_TOTAL
 	uint64_t total; //!< Total amount of RAM available in the system.
 #endif
