@@ -28,7 +28,7 @@
 /** \struct sa_net_interface network.h
  * This structure gathers the details about the activity of one network interface.
  */
-SA_EXPORT struct sa_net_interface {
+struct sa_net_interface {
 #ifdef SA_NET_INTERFACE_NAME
 	char name[SA_NET_INTERFACE_NAME]; //!< Interface's name. It's used as the unique identifier of the interface.
 #endif
