@@ -30,7 +30,7 @@
 /** \enum sa_process_state
  * The different types of states of a process.
  */
-SA_EXPORT enum sa_process_state {
+enum sa_process_state {
 	SA_UNKNOWN = 0, //!< The state is unknown.
 	SA_RUNNING = 1, //!< The process is running.
 	SA_SLEEPING = 2, //!< The process is sleeping.
@@ -42,7 +42,7 @@ SA_EXPORT enum sa_process_state {
 /** \struct sa_process_activity process.h
  * This structure holds the information of the activity of a process.
  */
-SA_EXPORT struct sa_process_activity {
+struct sa_process_activity {
 #ifdef SA_PROCESS_PID
 	pid_t pid; //!< The id of the process
 #endif
@@ -69,7 +69,7 @@ SA_EXPORT struct sa_process_activity {
 /** \struct sa_process process.h
  * This structure holds the static information about a process.
  */
-SA_EXPORT struct sa_process {
+struct sa_process {
 #ifdef SA_PROCESS_PID
 	pid_t pid; //!< The id of the process
 #endif
