@@ -23,6 +23,7 @@
 #include <pthread.h>
 #include <stdlib.h>
 #include <string.h>
+#include <math.h>
 
 #include "libsysactivity.h"
 
@@ -60,6 +61,7 @@ void print_cpu_info(struct sa_cpu* cpu) {
 }
 
 void check_range(float cpu_time) {
+	cpu_time = roundf(cpu_time);
 	if (cpu_time > 100.0 || cpu_time < 0.0) {
 		printf("%s:%d ERROR: cpu time out of range: %f\n", __FILE__, __LINE__, cpu_time);
 		error = 1;
@@ -105,6 +107,7 @@ void test_cpu_info(struct sa_cpu* cpu) {
 	sum += cpu->intr;
 #endif
 
+	check_range(sum);
 	if (sum < 90.0) // Sometimes it happens: user: 0.000000, nice: 0.000000, system: 0.000000, idle: 0.000000, waiting_for_io: 0.000000, hardware_irq: 0.000000, software_irq: 0.000000, stolen: 0.000000
 		printf("%s:%d WARNING: Summatory of all cpu times is lower than 90.0: %f\n", __FILE__, __LINE__, sum);
 }
